"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var docsPath = '/documentation/';
/**
 * Registers the hapi-swagger plugin and serves Swagger UI at `/documentation/`.
 */
exports.hapiApiDocs = function (server, options, next) {
    server.register({
        register: require('hapi-swagger'),
        options: {
            schemes: options.schemes,
            basePath: options.basePath,
            info: {
                title: options.pkg.name,
                version: options.pkg.version,
                description: options.pkg.description,
            },
            swaggerUI: false,
            documentationPage: false,
        },
    }, function (err) {
        if (err) {
            return next(err);
        }
        server.route({
            method: 'GET',
            path: docsPath + "{param*}",
            handler: {
                directory: {
                    path: 'node_modules/swagger-ui/dist/',
                },
            },
        });
        if (options.basePath !== '/') {
            // Ensure correct swagger.json path is passed to Swagger UI
            server.ext('onPreHandler', function (request, reply) {
                if (request.url.path === docsPath && !request.query.url) {
                    return reply.redirect("?url=" + options.basePath + "swagger.json");
                }
                return reply.continue();
            });
        }
        next();
    });
};
exports.hapiApiDocs.attributes = {
    pkg: require('../package.json'),
};
//# sourceMappingURL=index.js.map